# -*- encoding: utf-8 -*-

"""
Available vim plugins, addons, etc. that can be installed by vimp.

Copyright (C) 2014 Christian Stigen Larsen
Distributed under the LGPL v2.1; see LICENSE.txt
"""

__version__ = "0.4.9"

# Associates short script names with specific versions.
ALIASES = {
  "airline": "airline-0.6",
  "corporati": "corporati-1.0",
  "ctrlp": "ctrlp-1.79",
  "dispatch": "vim-dispatch-1.2",
  "easymotion": "easymotion-2.0",
  "fugitive": "fugitive-1.2",
  "fuzzyfinder": "fuzzyfinder-4.2.2",
  "guardian": "guardian-1.2",
  "l9": "l9-1.1",
  "matchit": "matchit-1.13.2",
  "nerdcommenter": "nerdcommenter-2.3.0",
  "nerdtree": "nerdtree-4.2.0",
  "pathogen": "pathogen-2.3",
  "powerline": "powerline-7.2",
  "signify": "signify-1.9",
  "snipmate": "snipmate-0.83",
  "surround": "surround-2.0",
  "syntastic": "syntastic-3.4.0",
  "taglist": "taglist-4.6",
  "undotree": "undotree-4.3",
  "vim-dispatch": "vim-dispatch-1.2",
}

# Known add-ons that can be installed by vimp
SCRIPTS = {
  "pathogen-2.3": {
    "author":   "Tim Pope",
    "about":    "Manages your runtimepath",
    "keywords": ["bundle"],
    "download": ("https://github.com/tpope/vim-pathogen/archive/v2.3.zip",
                 "{name}.zip"),
    "extract":  [ ("vim-pathogen-2.3/autoload/pathogen.vim", "{install}/autoload/pathogen.vim") ],
    "symlink":  [ ("{install}/autoload/pathogen.vim", "{vim}/autoload/pathogen.vim") ],
    "vimrc":    ["execute pathogen#infect()"],
  },

  "vim-dispatch-1.2": {
    "author": "Tim Pope",
    "about": "Asynchronous build and test dispatcher",
    "keywords": ["dispatch", "make", "background"],
    "download": ("https://github.com/tpope/vim-dispatch/archive/v1.2.tar.gz",
                 "{name}.tar.gz"),
    "extract": [ ("vim-dispatch-1.2/autoload/dispatch.vim",
                    "{install}/autoload/dispatch.vim"),
                 ("vim-dispatch-1.2/autoload/dispatch/headless.vim",
                     "{install}/autoload/dispatch/headless.vim"),
                 ("vim-dispatch-1.2/autoload/dispatch/iterm.vim",
                     "{install}/autoload/dispatch/iterm.vim"),
                 ("vim-dispatch-1.2/autoload/dispatch/screen.vim",
                     "{install}/autoload/dispatch/screen.vim"),
                 ("vim-dispatch-1.2/autoload/dispatch/tmux.vim",
                     "{install}/autoload/dispatch/tmux.vim"),
                 ("vim-dispatch-1.2/autoload/dispatch/windows.vim",
                     "{install}/autoload/dispatch/windows.vim"),
                 ("vim-dispatch-1.2/autoload/dispatch/x11.vim",
                     "{install}/autoload/dispatch/x11.vim"),
                 ("vim-dispatch-1.2/doc/dispatch.txt", "{install}/doc/dispatch.txt"),
                 ("vim-dispatch-1.2/plugin/dispatch.vim", "{install}/plugin/dispatch.vim")
                ],
    "symlink":  [ ("{install}", "{bundle}") ],
  },

  "nerdcommenter-2.3.0": {
    "author": "Marty Grenfell",
    "about": "Allows for easy commenting of code for many filetypes",
    "keywords": ["comment"],
    "download": ("http://www.vim.org/scripts/download_script.php?src_id=14455",
                 "{name}.zip"),
    "extract": [ ("doc/NERD_commenter.txt", "{install}/doc/NERD_commenter.txt"),
                 ("plugin/NERD_commenter.vim",
                  "{install}/plugin/NERD_commenter.vim") ],
    "symlink": [ ("{install}", "{bundle}") ],
    "print": ["You can use NERDCommenter by typing <leader>cc and <leader>cu",
              "which will comment and uncomment a line, respectively."]
  },

  "l9-1.1": {
    "author":   "Takeshi Nishida",
    "about":    "Programming library for vim",
    "keywords": [ "library" ],
    "download": ("http://www.vim.org/scripts/download_script.php?src_id=13948",
                 "{name}.zip"),
    "extract":  [ ("autoload/l9.vim", "{install}/autoload/l9.vim"),
                  ("autoload/l9/*", "{install}/autoload/l9"),
                  ("doc/*", "{install}/doc"),
                  ("plugin/*", "{install}/plugin") ],
    "symlink":  [ ("{install}", "{bundle}") ],
  },

  "taglist-4.6": {
    "author": "Yegappan Lakshmanan",
    "about": "Source code browser",
    "keywoeds": ["tag", "source", "browse", "c++", "python"],
    "download": ("http://vim.sourceforge.net/scripts/download_script.php?src_id=19574",
                 "{name}.zip"),
    "extract": [ ("doc/taglist.txt", "{install}/doc/taglist.txt"),
                 ("plugin/taglist.vim", "{install}/plugin/taglist.vim") ],
    "symlink": [ ("{install}", "{bundle}") ],
  },

  "fuzzyfinder-4.2.2": {
    "author": "Takeshi Nishida",
    "about": "Fuzzy search buffers, files, etc.",
    "keywords": ["search"],
    "deps": ["l9-1.1"],
    "download": ("http://www.vim.org/scripts/download_script.php?src_id=13961",
                 "{name}.zip"),
    "extract": [ ("autoload/fuf/*", "{install}/autoload/fuf"),
                 ("autoload/fuf.vim", "{install}/autoload/fuf.vim"),
                 ("doc/*", "{install}/doc"),
                 ("plugin/fuf.vim", "{install}/plugin/fuf.vim") ],
    "symlink": [ ("{install}", "{bundle}") ],
  },

  "ctrlp-1.79": {
    "author": "Kien Nguyen",
    "about": "Search anything anywhere anytime.",
    "keywords": ["search", "file", "navigation", "tree", "directory"],
    "download": ("http://www.vim.org/scripts/download_script.php?src_id=19448",
                 "{name}.zip"),
    "extract": [ ("autoload/ctrlp.vim", "{install}/autoload/ctrlp.vim"),
                 ("autoload/ctrlp/bookmarkdir.vim", "{install}/autoload/ctrlp/bookmarkdir.vim"),
                 ("autoload/ctrlp/buffertag.vim", "{install}/autoload/ctrlp/buffertag.vim"),
                 ("autoload/ctrlp/changes.vim", "{install}/autoload/ctrlp/changes.vim"),
                 ("autoload/ctrlp/dir.vim", "{install}/autoload/ctrlp/dir.vim"),
                 ("autoload/ctrlp/line.vim", "{install}/autoload/ctrlp/line.vim"),
                 ("autoload/ctrlp/mixed.vim", "{install}/autoload/ctrlp/mixed.vim"),
                 ("autoload/ctrlp/mrufiles.vim", "{install}/autoload/ctrlp/mrufiles.vim"),
                 ("autoload/ctrlp/quickfix.vim", "{install}/autoload/ctrlp/quickfix.vim"),
                 ("autoload/ctrlp/rtscript.vim", "{install}/autoload/ctrlp/rtscript.vim"),
                 ("autoload/ctrlp/tag.vim", "{install}/autoload/ctrlp/tag.vim"),
                 ("autoload/ctrlp/undo.vim", "{install}/autoload/ctrlp/undo.vim"),
                 ("autoload/ctrlp/utils.vim", "{install}/autoload/ctrlp/utils.vim"),
                 ("doc/ctrlp.txt", "{install}/doc/ctrlp.txt"),
                 ("plugin/ctrlp.vim", "{install}/plugin/ctrlp.vim") ],
    "symlink": [ ("{install}", "{bundle}") ],
  },

  "airline-0.6": {
    "author": "Bailey Ling",
    "about": "A lightweight status bar based on Powerline",
    "download": ("https://codeload.github.com/bling/vim-airline/tar.gz/v0.6",
                 "airline-0.6.tar.gz"),
    "keywords": [ "powerline", "status", "bar", "tabline" ],
    "symlink":  [ ("{install}", "{bundle}") ],
    "extract": [
      ("vim-airline-0.6/doc/airline.txt", "{install}/doc/airline.txt"),
      ("vim-airline-0.6/plugin/airline.vim", "{install}/plugin/airline.vim"),
      ("vim-airline-0.6/autoload/airline.vim", "{install}/autoload/airline.vim"),
      ("vim-airline-0.6/autoload/airline/builder.vim", "{install}/autoload/airline/builder.vim"),
      ("vim-airline-0.6/autoload/airline/debug.vim", "{install}/autoload/airline/debug.vim"),
      ("vim-airline-0.6/autoload/airline/deprecation.vim", "{install}/autoload/airline/deprecation.vim"),
      ("vim-airline-0.6/autoload/airline/extensions", "{install}/autoload/airline/extensions"),
      ("vim-airline-0.6/autoload/airline/extensions.vim", "{install}/autoload/airline/extensions.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/branch.vim", "{install}/autoload/airline/extensions/branch.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/bufferline.vim", "{install}/autoload/airline/extensions/bufferline.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/commandt.vim", "{install}/autoload/airline/extensions/commandt.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/csv.vim", "{install}/autoload/airline/extensions/csv.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/ctrlp.vim", "{install}/autoload/airline/extensions/ctrlp.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/default.vim", "{install}/autoload/airline/extensions/default.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/eclim.vim", "{install}/autoload/airline/extensions/eclim.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/example.vim", "{install}/autoload/airline/extensions/example.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/hunks.vim", "{install}/autoload/airline/extensions/hunks.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/syntastic.vim", "{install}/autoload/airline/extensions/syntastic.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/tabline", "{install}/autoload/airline/extensions/tabline"),
      ("vim-airline-0.6/autoload/airline/extensions/tabline.vim", "{install}/autoload/airline/extensions/tabline.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/tabline/formatters.vim", "{install}/autoload/airline/extensions/tabline/formatters.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/tagbar.vim", "{install}/autoload/airline/extensions/tagbar.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/undotree.vim", "{install}/autoload/airline/extensions/undotree.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/unite.vim", "{install}/autoload/airline/extensions/unite.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/virtualenv.vim", "{install}/autoload/airline/extensions/virtualenv.vim"),
      ("vim-airline-0.6/autoload/airline/extensions/whitespace.vim", "{install}/autoload/airline/extensions/whitespace.vim"),
      ("vim-airline-0.6/autoload/airline/highlighter.vim", "{install}/autoload/airline/highlighter.vim"),
      ("vim-airline-0.6/autoload/airline/init.vim", "{install}/autoload/airline/init.vim"),
      ("vim-airline-0.6/autoload/airline/parts.vim", "{install}/autoload/airline/parts.vim"),
      ("vim-airline-0.6/autoload/airline/section.vim", "{install}/autoload/airline/section.vim"),
      ("vim-airline-0.6/autoload/airline/themes", "{install}/autoload/airline/themes"),
      ("vim-airline-0.6/autoload/airline/themes.vim", "{install}/autoload/airline/themes.vim"),
      ("vim-airline-0.6/autoload/airline/themes/badwolf.vim", "{install}/autoload/airline/themes/badwolf.vim"),
      ("vim-airline-0.6/autoload/airline/themes/base16.vim", "{install}/autoload/airline/themes/base16.vim"),
      ("vim-airline-0.6/autoload/airline/themes/bubblegum.vim", "{install}/autoload/airline/themes/bubblegum.vim"),
      ("vim-airline-0.6/autoload/airline/themes/dark.vim", "{install}/autoload/airline/themes/dark.vim"),
      ("vim-airline-0.6/autoload/airline/themes/jellybeans.vim", "{install}/autoload/airline/themes/jellybeans.vim"),
      ("vim-airline-0.6/autoload/airline/themes/laederon.vim", "{install}/autoload/airline/themes/laederon.vim"),
      ("vim-airline-0.6/autoload/airline/themes/light.vim", "{install}/autoload/airline/themes/light.vim"),
      ("vim-airline-0.6/autoload/airline/themes/lucius.vim", "{install}/autoload/airline/themes/lucius.vim"),
      ("vim-airline-0.6/autoload/airline/themes/luna.vim", "{install}/autoload/airline/themes/luna.vim"),
      ("vim-airline-0.6/autoload/airline/themes/molokai.vim", "{install}/autoload/airline/themes/molokai.vim"),
      ("vim-airline-0.6/autoload/airline/themes/monochrome.vim", "{install}/autoload/airline/themes/monochrome.vim"),
      ("vim-airline-0.6/autoload/airline/themes/murmur.vim", "{install}/autoload/airline/themes/murmur.vim"),
      ("vim-airline-0.6/autoload/airline/themes/powerlineish.vim", "{install}/autoload/airline/themes/powerlineish.vim"),
      ("vim-airline-0.6/autoload/airline/themes/serene.vim", "{install}/autoload/airline/themes/serene.vim"),
      ("vim-airline-0.6/autoload/airline/themes/simple.vim", "{install}/autoload/airline/themes/simple.vim"),
      ("vim-airline-0.6/autoload/airline/themes/sol.vim", "{install}/autoload/airline/themes/sol.vim"),
      ("vim-airline-0.6/autoload/airline/themes/solarized.vim", "{install}/autoload/airline/themes/solarized.vim"),
      ("vim-airline-0.6/autoload/airline/themes/tomorrow.vim", "{install}/autoload/airline/themes/tomorrow.vim"),
      ("vim-airline-0.6/autoload/airline/themes/ubaryd.vim", "{install}/autoload/airline/themes/ubaryd.vim"),
      ("vim-airline-0.6/autoload/airline/themes/understated.vim", "{install}/autoload/airline/themes/understated.vim"),
      ("vim-airline-0.6/autoload/airline/themes/wombat.vim", "{install}/autoload/airline/themes/wombat.vim"),
      ("vim-airline-0.6/autoload/airline/themes/zenburn.vim", "{install}/autoload/airline/themes/zenburn.vim"),
      ("vim-airline-0.6/autoload/airline/util.vim", "{install}/autoload/airline/util.vim"),
      ("vim-airline-0.6/t/airline.vim", "{install}/t/airline.vim"),
      ("vim-airline-0.6/t/builder.vim", "{install}/t/builder.vim"),
      ("vim-airline-0.6/t/commands.vim", "{install}/t/commands.vim"),
      ("vim-airline-0.6/t/extensions_default.vim", "{install}/t/extensions_default.vim"),
      ("vim-airline-0.6/t/highlighter.vim", "{install}/t/highlighter.vim"),
      ("vim-airline-0.6/t/init.vim", "{install}/t/init.vim"),
      ("vim-airline-0.6/t/parts.vim", "{install}/t/parts.vim"),
      ("vim-airline-0.6/t/section.vim", "{install}/t/section.vim"),
      ("vim-airline-0.6/t/themes.vim", "{install}/t/themes.vim"),
      ("vim-airline-0.6/t/util.vim", "{install}/t/util.vim"),
    ],
  },

  "airline-powerline-fonts": {
    "about": "Airline with the old Powerline symbols",
    "deps": ["airline"],
    "embed": [("{install}/plugin/airline-powerline-fonts.vim",
               """" old vim-powerline symbols
if !exists('g:airline_symbols')
  let g:airline_symbols = {{}}
endif

let g:airline_left_sep = '⮀'
let g:airline_left_alt_sep = '⮁'
let g:airline_right_sep = '⮂'
let g:airline_right_alt_sep = '⮃'
let g:airline_symbols.branch = '⭠'
let g:airline_symbols.readonly = '⭤'
let g:airline_symbols.linenr = '⭡'
""")],
    "symlink": [("{install}", "{bundle}")],
  },

  "powerline-7.2": {
    "author": "Kim Silkebækken",
    "about": "Awesome status bar.",
    "keywords": ["status", "bar", "tabline"],
    "download": ("http://www.vim.org/scripts/download_script.php?src_id=17546",
                 "{name}.tar.gz"),
    "extract": [
      ("Lokaltog-vim-powerline-d885f90/autoload/Pl.vim",
       "{install}/autoload/Pl.vim"),
      ("Lokaltog-vim-powerline-d885f90/autoload/Pl/*",
       "{install}/autoload/Pl"),
      ("Lokaltog-vim-powerline-d885f90/autoload/Powerline/Colorschemes/*",
       "{install}/autoload/Powerline/Colorschemes"),
      ("Lokaltog-vim-powerline-d885f90/autoload/Powerline/Functions/*",
       "{install}/autoload/Powerline/Functions"),
      ("Lokaltog-vim-powerline-d885f90/autoload/Powerline/Segments/*",
       "{install}/autoload/Powerline/Segments"),
      ("Lokaltog-vim-powerline-d885f90/autoload/Powerline/Themes/*",
       "{install}/autoload/Powerline/Themes"),
      ("Lokaltog-vim-powerline-d885f90/autoload/Powerline/Functions.vim",
       "{install}/autoload/Powerline/Functions.vim"),
      ("Lokaltog-vim-powerline-d885f90/autoload/Powerline/Matches.vim",
       "{install}/autoload/Powerline/Matches.vim"),
      ("Lokaltog-vim-powerline-d885f90/autoload/Powerline/Segments.vim",
       "{install}/autoload/Powerline/Segments.vim"),
      ("Lokaltog-vim-powerline-d885f90/doc/*",
       "{install}/doc"),
      ("Lokaltog-vim-powerline-d885f90/plugin/*",
       "{install}/plugin")
    ],
    "symlink": [ ("{install}", "{bundle}") ]
  },

  "molokai": {
    "author": "Tomas Restrepo",
    "about": "The Molokai color scheme.",
    "keywords": ["color", "pink", "green"],
    "download": ("https://raw.githubusercontent.com/tomasr/molokai/master/colors/molokai.vim",
                 "{name}.vim"),
    "copy": [ ("{download}/{name}.vim", "{install}/{name}.vim") ],
    "symlink": [ ("{install}/{name}.vim", "{colors}/{name}.vim") ],
    "vimrc": ["colorscheme {name}"],
  },

  "solarized": {
    "author": "Ethan Schoonover",
    "about": "The Solarized color scheme.",
    "keywords": ["color", "blue"],
    "download": ("https://raw.githubusercontent.com/altercation/vim-colors-solarized/master/colors/solarized.vim",
                 "{name}.vim"),
    "copy": [ ("{download}/{name}.vim", "{install}/{name}.vim") ],
    "symlink": [ ("{install}/{name}.vim", "{colors}/{name}.vim") ],
    "vimrc": ["colorscheme {name}"],
  },

  "grb256": {
    "author": "Gary Bernhardt",
    "about": "The grb256 color scheme.",
    "keywords": ["color"],
    "download": ("https://raw.githubusercontent.com/garybernhardt/dotfiles/master/.vim/colors/grb256.vim",
                 "grb256.vim"),
    "copy": [ ("{download}/grb256.vim", "{install}/grb256.vim") ],
    "symlink": [ ("{install}/grb256.vim", "{colors}/grb256.vim") ],
    "vimrc": ["colorscheme grb256"],
  },

  "guardian-1.2": {
    "author": "M. L. (anderskorte)",
    "vim-version": "6.0",
    "about": "The {name} color scheme.",
    "keywords": ["color", "red", "coffee"],
    "download": ("http://www.vim.org/scripts/download_script.php?src_id=4128",
                 "guardian.vim"),
    "copy": [ ("{download}/guardian.vim", "{install}/guardian.vim") ],
    "symlink": [ ("{install}/guardian.vim", "{colors}/guardian.vim") ],
    "vimrc": ["colorscheme {name}"],
  },

  "corporati-1.0": {
    "author": "Christian Stigen Larsen",
    "about": "The {name} color scheme.",
    "keywords": ["pink", "purple"],
    "download": ("https://raw.githubusercontent.com/cslarsen/vim-corporati/master/colors/corporati.vim",
                 "corporati.vim"),
    "copy": [ ("{download}/corporati.vim", "{install}/corporati.vim") ],
    "symlink": [ ("{install}/corporati.vim", "{colors}/corporati.vim") ],
    "vimrc": ["colorscheme {name}"],
  },

  "nerdtree-4.2.0": {
    "author": "Marty Grenfell",
    "vim-version": "7.0",
    "about": "File explorer.",
    "keywords": ["file", "tree", "directory", "explore"],
    "download": ("http://www.vim.org/scripts/download_script.php?src_id=17123",
                 "nerdtree-4.2.0.zip"),
    "extract": [ ("doc/NERD_tree.txt", "{install}/doc/NERD_tree.txt"),
                 ("plugin/NERD_tree.vim", "{install}/plugin/NERD_tree.vim"),
                 ("nerdtree_plugin/exec_menuitem.vim", "{install}/nerdtree_plugin/exec_menuitem.vim"),
                 ("nerdtree_plugin/fs_menu.vim", "{install}/nerdtree_plugin/fs_menu.vim"),
                 ("syntax/nerdtree.vim", "{install}/syntax/nerdtree.vim"), ],
    "symlink": [ ("{install}", "{bundle}") ],
    "print": ["To bind :NERDTreeToggle to CTRL+d, install: nerdtree@ctrl-d"],
  },

  "nerdtree@ctrl-d": {
    "author": "Christian Stigen Larsen",
    "about": "Maps Nerdtree to <C-d>",
    "deps": ["nerdtree"],
    "embed": [("{install}/plugin/nerdtree@ctrl-d/nerdtree@ctrl-d.vim",
               "nmap <silent> <C-d> :NERDTreeToggle<Cr>")],
    "symlink": [("{install}", "{bundle}")],
  },

  "taglist@ctrl-a": {
    "author": "Christian Stigen Larsen",
    "about": "Maps Taglist to <C-a>",
    "deps": ["taglist"],
    "embed": [("{install}/plugin/taglist@ctrl-a/taglist@ctrl-a.vim",
               "nmap <silent> <C-a> :TlistToggle<Cr>")],
    "symlink": [("{install}", "{bundle}")],
  },

  "invnumber@ctrl-n": {
    "author": "Christian Stigen Larsen",
    "about": "Toggle display of linenumbers by mapping :set invnumber to <C-n>",
    "embed": [("{install}/plugin/invnumber@ctrl-n.vim",
               "nmap <silent> <C-n> :set invnumber<Cr>")],
    "symlink": [("{install}", "{bundle}")],
  },

  "colorcolumn": {
    "author": "Christian Stigen Larsen",
    "about": "Shows a vertical line at the 81th column",
    "embed": [("{install}/plugin/colorcolumn.vim",
               """" Show a vertical line at the 81th column
set colorcolumn=81
highlight ColorColumn ctermbg=234
""")],
    "symlink": [("{install}", "{bundle}")],
  },

  "nohlsearch@ctrl-o": {
    "author": "Christian Stigen Larsen",
    "about": "Maps :nohlsearch to <C-o>",
    "embed": [("{install}/plugin/nohlsearch@ctrl-o.vim",
               """" Turns off search highlighting with <C-o>
nmap <silent> <C-o> :nohlsearch<Cr>
""")],
    "symlink": [("{install}", "{bundle}")],
  },

  "tabs@ctrl-lhtk": {
    "author": "Christian Stigen Larsen",
    "about": "Maps tab open to <C-t>, close to <C-k>, switch to <C-h> and <C-l>",
    "embed": [("{install}/plugin/tabs@ctrl-lhtk/tabs@ctrl-lhtk.vim",
               """
nmap <silent> <C-t> :tabnew<Cr>
nmap <silent> <C-k> :tabclose<Cr>
nmap <silent> <C-h> :tabprev<Cr>
nmap <silent> <C-l> :tabnext<Cr>
""")],
    "symlink": [("{install}", "{bundle}")],
  },

  "leader@comma": {
    "author": "Christian Stigen Larsen",
    "about": "Maps <leader> to comma instead of default \\,",
    "embed": [("{install}/plugin/leader@comma.vim", 'let mapleader = ","')],
    "symlink": [("{install}", "{bundle}")],
  },

  "forcequit@ctrl-x": {
    "author": "Christian Stigen Larsen",
    "about": "Maps :q! to <C-x>",
    "embed": [("{install}/plugin/forcequit@ctrl-x/forcequit@ctrl-x.vim",
               "nmap <silent> <C-x> :q!<Cr>")],
    "symlink": [("{install}", "{bundle}")],
  },

  "surround-2.0": {
    "author": "Tim Pope",
    "about": "Quoting and parenthesizing made simple.",
    "keywords": ["quote"],
    "download": ("https://github.com/tpope/vim-surround/archive/v2.0.zip",
                 "surround-2.0.zip"),
    "extract": [ ("vim-surround-2.0/doc/surround.txt",
                  "{install}/doc/surround.txt"),
                 ("vim-surround-2.0/plugin/surround.vim",
                  "{install}/plugin/surround.vim") ],
    "symlink": [ ("{install}", "{bundle}") ],
  },

  "signify-1.9": {
    "author": "Marco Hinz",
    "about": "Mark version controlled file changes in the sign column.",
    "keywords": ["git", "diff", "hg", "svn", "darcs", "bzr", "fossil",
                 "cvs", "rcs"],
    "download": ("https://codeload.github.com/mhinz/vim-signify/tar.gz/1.9",
                 "signify-1.9.tar.gz"),
    "extract": [ ("vim-signify-1.9/doc/signify.txt", "{install}/doc/signify.txt"),
                 ("vim-signify-1.9/plugin/signify.vim", "{install}/plugin/signify.vim") ],
    "symlink": [ ("{install}", "{bundle}") ],
    "print": [ "To restrict signify to git, install: signify-git"],
  },

  "signify-git": {
    "author": "Christian Stigen Larsen",
    "about": "Restricts signify to only git files",
    "deps": ["signify"],
    "embed": [
      ("{install}/plugin/signify-git.vim",
       "let g:signify_vcs_list = [ 'git' ]\n")
    ],
    "symlink": [ ("{install}", "{bundle}") ],
  },

  "easymotion-2.0": {
    "author":   "Kim Silkebækken",
    "about":    "Vim motions on speed",
    "keywords": ["movement"],
    "download": ("https://codeload.github.com/Lokaltog/vim-easymotion/tar.gz/2.0",
                 "easymotion-2.0.tar.gz"),
    "extract": [
      ("vim-easymotion-2.0/autoload/EasyMotion", "{install}/autoload/EasyMotion"),
      ("vim-easymotion-2.0/autoload/EasyMotion.vim", "{install}/autoload/EasyMotion.vim"),
      ("vim-easymotion-2.0/autoload/EasyMotion/cmigemo.vim", "{install}/autoload/EasyMotion/cmigemo.vim"),
      ("vim-easymotion-2.0/autoload/EasyMotion/command_line.vim", "{install}/autoload/EasyMotion/command_line.vim"),
      ("vim-easymotion-2.0/autoload/EasyMotion/helper.vim", "{install}/autoload/EasyMotion/helper.vim"),
      ("vim-easymotion-2.0/autoload/EasyMotion/highlight.vim", "{install}/autoload/EasyMotion/highlight.vim"),
      ("vim-easymotion-2.0/autoload/EasyMotion/init.vim", "{install}/autoload/EasyMotion/init.vim"),
      ("vim-easymotion-2.0/autoload/EasyMotion/migemo", "{install}/autoload/EasyMotion/migemo"),
      ("vim-easymotion-2.0/autoload/EasyMotion/migemo/cp932.vim", "{install}/autoload/EasyMotion/migemo/cp932.vim"),
      ("vim-easymotion-2.0/autoload/EasyMotion/migemo/eucjp.vim", "{install}/autoload/EasyMotion/migemo/eucjp.vim"),
      ("vim-easymotion-2.0/autoload/EasyMotion/migemo/utf8.vim", "{install}/autoload/EasyMotion/migemo/utf8.vim"),
      ("vim-easymotion-2.0/autoload/EasyMotion/sticky_table.vim", "{install}/autoload/EasyMotion/sticky_table.vim"),
      ("vim-easymotion-2.0/autoload/vital", "{install}/autoload/vital"),
      ("vim-easymotion-2.0/autoload/vital.vim", "{install}/autoload/vital.vim"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion", "{install}/autoload/vital/_easymotion"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion.vim", "{install}/autoload/vital/_easymotion.vim"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over", "{install}/autoload/vital/_easymotion/Over"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over/Commandline", "{install}/autoload/vital/_easymotion/Over/Commandline"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over/Commandline.vim", "{install}/autoload/vital/_easymotion/Over/Commandline.vim"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over/Commandline/Modules", "{install}/autoload/vital/_easymotion/Over/Commandline/Modules"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over/Commandline/Modules/BufferComplete.vim", "{install}/autoload/vital/_easymotion/Over/Commandline/Modules/BufferComplete.vim"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over/Commandline/Modules/Cancel.vim", "{install}/autoload/vital/_easymotion/Over/Commandline/Modules/Cancel.vim"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over/Commandline/Modules/CursorMove.vim", "{install}/autoload/vital/_easymotion/Over/Commandline/Modules/CursorMove.vim"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over/Commandline/Modules/Delete.vim", "{install}/autoload/vital/_easymotion/Over/Commandline/Modules/Delete.vim"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over/Commandline/Modules/Enter.vim", "{install}/autoload/vital/_easymotion/Over/Commandline/Modules/Enter.vim"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over/Commandline/Modules/HistAdd.vim", "{install}/autoload/vital/_easymotion/Over/Commandline/Modules/HistAdd.vim"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over/Commandline/Modules/History.vim", "{install}/autoload/vital/_easymotion/Over/Commandline/Modules/History.vim"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over/Commandline/Modules/Incsearch.vim", "{install}/autoload/vital/_easymotion/Over/Commandline/Modules/Incsearch.vim"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over/Commandline/Modules/NoInsert.vim", "{install}/autoload/vital/_easymotion/Over/Commandline/Modules/NoInsert.vim"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over/Commandline/Modules/Paste.vim", "{install}/autoload/vital/_easymotion/Over/Commandline/Modules/Paste.vim"),
      ("vim-easymotion-2.0/autoload/vital/_easymotion/Over/Commandline/Modules/Scroll.vim", "{install}/autoload/vital/_easymotion/Over/Commandline/Modules/Scroll.vim"),
      ("vim-easymotion-2.0/autoload/vital/easymotion.vital", "{install}/autoload/vital/easymotion.vital"),
      ("vim-easymotion-2.0/doc/easymotion.txt", "{install}/doc/easymotion.txt"),
      ("vim-easymotion-2.0/plugin/EasyMotion.vim", "{install}/plugin/EasyMotion.vim"),
      ("vim-easymotion-2.0/t/easymotion_spec.vim", "{install}/t/easymotion_spec.vim"),
    ],
    "symlink": [ ("{install}", "{bundle}") ],
  },

  "fugitive-2.0.beta": {
    "author": "Tim Pope",
    "about": "Git in vim",
    "keywords": ["git", "diff"],
    "download": ("https://codeload.github.com/tpope/vim-fugitive/tar.gz/v2.0.beta",
                 "fugitive-2.0.beta.tar.gz"),
    "extract": [
      ("vim-fugitive-2.0.beta/doc/fugitive.txt",
       "{install}/doc/fugitive.txt"),
      ("vim-fugitive-2.0.beta/plugin/fugitive.vim",
       "{install}/plugin/fugitive.vim") ],
    "symlink": [ ("{install}", "{bundle}") ],
    "print": [
"""
To get quickly started with Fugitive, open up a file in a git repository,
then type stuff like `:Gdiff`, `:Gstatus`, `:Glog`, `:Gblame`, `:Gbrowse`
and of course `:help fugitive`.
""" ],
  },

  "fugitive-1.2": {
    "author": "Tim Pope",
    "about": "Git in vim",
    "keywords": ["git", "diff"],
    "download": ("https://codeload.github.com/tpope/vim-fugitive/tar.gz/v1.2",
                 "fugitive-1.2.tar.gz"),
    "extract": [
      ("vim-fugitive-1.2/doc/fugitive.txt", "{install}/doc/fugitive.txt"),
      ("vim-fugitive-1.2/plugin/fugitive.vim", "{install}/plugin/fugitive.vim") ],
    "symlink": [ ("{install}", "{bundle}") ],
    "print": [
"""
To get quickly started with Fugitive, open up a file in a git repository,
then type stuff like `:Gdiff`, `:Gstatus`, `:Glog`, `:Gblame`, `:Gbrowse`
and of course `:help fugitive`.
""" ],
  },

  "undotree-4.3": {
    "author": "Ming, Bai",
    "about": "Graph your undo history.",
    "download": ("https://codeload.github.com/mbbill/undotree/tar.gz/rel_4.3",
                 "undotree-4.3.tar.gz"),
    "extract": [
      ("undotree-rel_4.3/plugin/undotree.vim",
       "{install}/plugin/undotree.vim"),
      ("undotree-rel_4.3/syntax/undotree.vim",
       "{install}/syntax/undotree.vim") ],
    "symlink": [ ("{install}", "{bundle}") ],
    "print": ["To map :UndotreeToggle to CTRL+u, install: undotree@ctrl-u"],
  },

  "undotree@ctrl-u": {
    "author": "Christian Stigen Larsen",
    "about": "Maps UndotreeToggle to <C-u>",
    "deps": ["undotree"],
    "embed": [
      ("{install}/plugin/undotree@ctrl-u.vim",
       ":nmap <silent> <C-u> :UndotreeToggle<Cr>")
    ],
    "symlink": [ ("{install}", "{bundle}") ],
  },

  "matchit-1.13.2": {
    "author": "Benji Fisher",
    "about": "Have % match anything from HTML to code.",
    "download": ("http://www.vim.org/scripts/download_script.php?src_id=8196",
                 "matchit-1.13.2.zip"),
    "extract": [
      ("doc/matchit.txt", "{install}/doc/matchit.txt"),
      ("plugin/matchit.vim", "{install}/plugin/matchit.vim"),
    ],
    "symlink": [ ("{install}", "{bundle}") ],
  },

  "snipmate-0.83": {
    "author": "Michael Sanders",
    "about": "Tab-completion for boilerplate code.",
    "download":
        ("http://www.vim.org/scripts/download_script.php?src_id=11006",
         "snipmate-0.83.zip"),
    "extract": [
        ("after/plugin/snipMate.vim", "{install}/after/plugin/snipMate.vim"),
        ("autoload/snipMate.vim", "{install}/autoload/snipMate.vim"),
        ("doc/snipMate.txt", "{install}/doc/snipMate.txt"),
        ("ftplugin/html_snip_helper.vim", "{install}/ftplugin/html_snip_helper.vim"),
        ("plugin/snipMate.vim", "{install}/plugin/snipMate.vim"),
        ("snippets/_.snippets", "{install}/snippets/_.snippets"),
        ("snippets/autoit.snippets", "{install}/snippets/autoit.snippets"),
        ("snippets/c.snippets", "{install}/snippets/c.snippets"),
        ("snippets/cpp.snippets", "{install}/snippets/cpp.snippets"),
        ("snippets/html.snippets", "{install}/snippets/html.snippets"),
        ("snippets/java.snippets", "{install}/snippets/java.snippets"),
        ("snippets/javascript.snippets", "{install}/snippets/javascript.snippets"),
        ("snippets/mako.snippets", "{install}/snippets/mako.snippets"),
        ("snippets/objc.snippets", "{install}/snippets/objc.snippets"),
        ("snippets/perl.snippets", "{install}/snippets/perl.snippets"),
        ("snippets/php.snippets", "{install}/snippets/php.snippets"),
        ("snippets/python.snippets", "{install}/snippets/python.snippets"),
        ("snippets/ruby.snippets", "{install}/snippets/ruby.snippets"),
        ("snippets/sh.snippets", "{install}/snippets/sh.snippets"),
        ("snippets/snippet.snippets", "{install}/snippets/snippet.snippets"),
        ("snippets/tcl.snippets", "{install}/snippets/tcl.snippets"),
        ("snippets/tex.snippets", "{install}/snippets/tex.snippets"),
        ("snippets/vim.snippets", "{install}/snippets/vim.snippets"),
        ("snippets/zsh.snippets", "{install}/snippets/zsh.snippets"),
        ("syntax/snippet.vim", "{install}/syntax/snippet.vim"),
    ],
    "symlink": [ ("{install}", "{bundle}") ],
  },

  "syntastic-3.4.0": {
    "author": "Martin Grenfell",
    "about": "Syntax-checker for programming languages.",
    "download":
      ("https://codeload.github.com/scrooloose/syntastic/tar.gz/3.4.0",
       "syntastic-3.4.0.tar.gz"),
    "extract": [
      ("syntastic-3.4.0/autoload/c.vim", "{install}/autoload/c.vim"),
      ("syntastic-3.4.0/autoload/log.vim", "{install}/autoload/log.vim"),
      ("syntastic-3.4.0/autoload/postprocess.vim", "{install}/autoload/postprocess.vim"),
      ("syntastic-3.4.0/autoload/preprocess.vim", "{install}/autoload/preprocess.vim"),
      ("syntastic-3.4.0/autoload/util.vim", "{install}/autoload/util.vim"),
      ("syntastic-3.4.0/doc/syntastic.txt", "{install}/doc/syntastic.txt"),
      ("syntastic-3.4.0/plugin/syntastic.vim", "{install}/plugin/syntastic.vim"),
      ("syntastic-3.4.0/plugin/syntastic/autoloclist.vim", "{install}/plugin/syntastic/autoloclist.vim"),
      ("syntastic-3.4.0/plugin/syntastic/balloons.vim", "{install}/plugin/syntastic/balloons.vim"),
      ("syntastic-3.4.0/plugin/syntastic/checker.vim", "{install}/plugin/syntastic/checker.vim"),
      ("syntastic-3.4.0/plugin/syntastic/cursor.vim", "{install}/plugin/syntastic/cursor.vim"),
      ("syntastic-3.4.0/plugin/syntastic/highlighting.vim", "{install}/plugin/syntastic/highlighting.vim"),
      ("syntastic-3.4.0/plugin/syntastic/loclist.vim", "{install}/plugin/syntastic/loclist.vim"),
      ("syntastic-3.4.0/plugin/syntastic/modemap.vim", "{install}/plugin/syntastic/modemap.vim"),
      ("syntastic-3.4.0/plugin/syntastic/notifiers.vim", "{install}/plugin/syntastic/notifiers.vim"),
      ("syntastic-3.4.0/plugin/syntastic/registry.vim", "{install}/plugin/syntastic/registry.vim"),
      ("syntastic-3.4.0/plugin/syntastic/signs.vim", "{install}/plugin/syntastic/signs.vim"),
      ("syntastic-3.4.0/syntax_checkers/actionscript/mxmlc.vim", "{install}/syntax_checkers/actionscript/mxmlc.vim"),
      ("syntastic-3.4.0/syntax_checkers/ada/gcc.vim", "{install}/syntax_checkers/ada/gcc.vim"),
      ("syntastic-3.4.0/syntax_checkers/applescript/osacompile.vim", "{install}/syntax_checkers/applescript/osacompile.vim"),
      ("syntastic-3.4.0/syntax_checkers/asciidoc/asciidoc.vim", "{install}/syntax_checkers/asciidoc/asciidoc.vim"),
      ("syntastic-3.4.0/syntax_checkers/asm/gcc.vim", "{install}/syntax_checkers/asm/gcc.vim"),
      ("syntastic-3.4.0/syntax_checkers/bemhtml/bemhtmllint.vim", "{install}/syntax_checkers/bemhtml/bemhtmllint.vim"),
      ("syntastic-3.4.0/syntax_checkers/c/avrgcc.vim", "{install}/syntax_checkers/c/avrgcc.vim"),
      ("syntastic-3.4.0/syntax_checkers/c/checkpatch.vim", "{install}/syntax_checkers/c/checkpatch.vim"),
      ("syntastic-3.4.0/syntax_checkers/c/cppcheck.vim", "{install}/syntax_checkers/c/cppcheck.vim"),
      ("syntastic-3.4.0/syntax_checkers/c/gcc.vim", "{install}/syntax_checkers/c/gcc.vim"),
      ("syntastic-3.4.0/syntax_checkers/c/make.vim", "{install}/syntax_checkers/c/make.vim"),
      ("syntastic-3.4.0/syntax_checkers/c/oclint.vim", "{install}/syntax_checkers/c/oclint.vim"),
      ("syntastic-3.4.0/syntax_checkers/c/sparse.vim", "{install}/syntax_checkers/c/sparse.vim"),
      ("syntastic-3.4.0/syntax_checkers/c/splint.vim", "{install}/syntax_checkers/c/splint.vim"),
      ("syntastic-3.4.0/syntax_checkers/chef/foodcritic.vim", "{install}/syntax_checkers/chef/foodcritic.vim"),
      ("syntastic-3.4.0/syntax_checkers/co/coco.vim", "{install}/syntax_checkers/co/coco.vim"),
      ("syntastic-3.4.0/syntax_checkers/cobol/cobc.vim", "{install}/syntax_checkers/cobol/cobc.vim"),
      ("syntastic-3.4.0/syntax_checkers/coffee/coffee.vim", "{install}/syntax_checkers/coffee/coffee.vim"),
      ("syntastic-3.4.0/syntax_checkers/coffee/coffeelint.vim", "{install}/syntax_checkers/coffee/coffeelint.vim"),
      ("syntastic-3.4.0/syntax_checkers/coq/coqtop.vim", "{install}/syntax_checkers/coq/coqtop.vim"),
      ("syntastic-3.4.0/syntax_checkers/cpp/cppcheck.vim", "{install}/syntax_checkers/cpp/cppcheck.vim"),
      ("syntastic-3.4.0/syntax_checkers/cpp/cpplint.vim", "{install}/syntax_checkers/cpp/cpplint.vim"),
      ("syntastic-3.4.0/syntax_checkers/cpp/gcc.vim", "{install}/syntax_checkers/cpp/gcc.vim"),
      ("syntastic-3.4.0/syntax_checkers/cpp/oclint.vim", "{install}/syntax_checkers/cpp/oclint.vim"),
      ("syntastic-3.4.0/syntax_checkers/cs/mcs.vim", "{install}/syntax_checkers/cs/mcs.vim"),
      ("syntastic-3.4.0/syntax_checkers/css/csslint.vim", "{install}/syntax_checkers/css/csslint.vim"),
      ("syntastic-3.4.0/syntax_checkers/css/phpcs.vim", "{install}/syntax_checkers/css/phpcs.vim"),
      ("syntastic-3.4.0/syntax_checkers/css/prettycss.vim", "{install}/syntax_checkers/css/prettycss.vim"),
      ("syntastic-3.4.0/syntax_checkers/cucumber/cucumber.vim", "{install}/syntax_checkers/cucumber/cucumber.vim"),
      ("syntastic-3.4.0/syntax_checkers/cuda/nvcc.vim", "{install}/syntax_checkers/cuda/nvcc.vim"),
      ("syntastic-3.4.0/syntax_checkers/d/dmd.vim", "{install}/syntax_checkers/d/dmd.vim"),
      ("syntastic-3.4.0/syntax_checkers/dart/dartanalyzer.vim", "{install}/syntax_checkers/dart/dartanalyzer.vim"),
      ("syntastic-3.4.0/syntax_checkers/docbk/xmllint.vim", "{install}/syntax_checkers/docbk/xmllint.vim"),
      ("syntastic-3.4.0/syntax_checkers/dustjs/swiffer.vim", "{install}/syntax_checkers/dustjs/swiffer.vim"),
      ("syntastic-3.4.0/syntax_checkers/elixir/elixir.vim", "{install}/syntax_checkers/elixir/elixir.vim"),
      ("syntastic-3.4.0/syntax_checkers/erlang/erlang_check_file.erl", "{install}/syntax_checkers/erlang/erlang_check_file.erl"),
      ("syntastic-3.4.0/syntax_checkers/erlang/escript.vim", "{install}/syntax_checkers/erlang/escript.vim"),
      ("syntastic-3.4.0/syntax_checkers/erlang/syntaxerl.vim", "{install}/syntax_checkers/erlang/syntaxerl.vim"),
      ("syntastic-3.4.0/syntax_checkers/eruby/ruby.vim", "{install}/syntax_checkers/eruby/ruby.vim"),
      ("syntastic-3.4.0/syntax_checkers/fortran/gfortran.vim", "{install}/syntax_checkers/fortran/gfortran.vim"),
      ("syntastic-3.4.0/syntax_checkers/glsl/cgc.vim", "{install}/syntax_checkers/glsl/cgc.vim"),
      ("syntastic-3.4.0/syntax_checkers/go/go.vim", "{install}/syntax_checkers/go/go.vim"),
      ("syntastic-3.4.0/syntax_checkers/go/gofmt.vim", "{install}/syntax_checkers/go/gofmt.vim"),
      ("syntastic-3.4.0/syntax_checkers/go/golint.vim", "{install}/syntax_checkers/go/golint.vim"),
      ("syntastic-3.4.0/syntax_checkers/go/gotype.vim", "{install}/syntax_checkers/go/gotype.vim"),
      ("syntastic-3.4.0/syntax_checkers/go/govet.vim", "{install}/syntax_checkers/go/govet.vim"),
      ("syntastic-3.4.0/syntax_checkers/haml/haml.vim", "{install}/syntax_checkers/haml/haml.vim"),
      ("syntastic-3.4.0/syntax_checkers/haml/haml_lint.vim", "{install}/syntax_checkers/haml/haml_lint.vim"),
      ("syntastic-3.4.0/syntax_checkers/handlebars/handlebars.vim", "{install}/syntax_checkers/handlebars/handlebars.vim"),
      ("syntastic-3.4.0/syntax_checkers/haskell/ghc-mod.vim", "{install}/syntax_checkers/haskell/ghc-mod.vim"),
      ("syntastic-3.4.0/syntax_checkers/haskell/hdevtools.vim", "{install}/syntax_checkers/haskell/hdevtools.vim"),
      ("syntastic-3.4.0/syntax_checkers/haskell/hlint.vim", "{install}/syntax_checkers/haskell/hlint.vim"),
      ("syntastic-3.4.0/syntax_checkers/haxe/haxe.vim", "{install}/syntax_checkers/haxe/haxe.vim"),
      ("syntastic-3.4.0/syntax_checkers/hss/hss.vim", "{install}/syntax_checkers/hss/hss.vim"),
      ("syntastic-3.4.0/syntax_checkers/html/jshint.vim", "{install}/syntax_checkers/html/jshint.vim"),
      ("syntastic-3.4.0/syntax_checkers/html/tidy.vim", "{install}/syntax_checkers/html/tidy.vim"),
      ("syntastic-3.4.0/syntax_checkers/html/validator.vim", "{install}/syntax_checkers/html/validator.vim"),
      ("syntastic-3.4.0/syntax_checkers/html/w3.vim", "{install}/syntax_checkers/html/w3.vim"),
      ("syntastic-3.4.0/syntax_checkers/java/checkstyle.vim", "{install}/syntax_checkers/java/checkstyle.vim"),
      ("syntastic-3.4.0/syntax_checkers/java/javac.vim", "{install}/syntax_checkers/java/javac.vim"),
      ("syntastic-3.4.0/syntax_checkers/javascript/closurecompiler.vim", "{install}/syntax_checkers/javascript/closurecompiler.vim"),
      ("syntastic-3.4.0/syntax_checkers/javascript/eslint.vim", "{install}/syntax_checkers/javascript/eslint.vim"),
      ("syntastic-3.4.0/syntax_checkers/javascript/gjslint.vim", "{install}/syntax_checkers/javascript/gjslint.vim"),
      ("syntastic-3.4.0/syntax_checkers/javascript/jscs.vim", "{install}/syntax_checkers/javascript/jscs.vim"),
      ("syntastic-3.4.0/syntax_checkers/javascript/jshint.vim", "{install}/syntax_checkers/javascript/jshint.vim"),
      ("syntastic-3.4.0/syntax_checkers/javascript/jsl.vim", "{install}/syntax_checkers/javascript/jsl.vim"),
      ("syntastic-3.4.0/syntax_checkers/javascript/jslint.vim", "{install}/syntax_checkers/javascript/jslint.vim"),
      ("syntastic-3.4.0/syntax_checkers/javascript/jsxhint.vim", "{install}/syntax_checkers/javascript/jsxhint.vim"),
      ("syntastic-3.4.0/syntax_checkers/json/jsonlint.vim", "{install}/syntax_checkers/json/jsonlint.vim"),
      ("syntastic-3.4.0/syntax_checkers/json/jsonval.vim", "{install}/syntax_checkers/json/jsonval.vim"),
      ("syntastic-3.4.0/syntax_checkers/less/less-lint.coffee", "{install}/syntax_checkers/less/less-lint.coffee"),
      ("syntastic-3.4.0/syntax_checkers/less/less-lint.js", "{install}/syntax_checkers/less/less-lint.js"),
      ("syntastic-3.4.0/syntax_checkers/less/lessc.vim", "{install}/syntax_checkers/less/lessc.vim"),
      ("syntastic-3.4.0/syntax_checkers/lex/flex.vim", "{install}/syntax_checkers/lex/flex.vim"),
      ("syntastic-3.4.0/syntax_checkers/limbo/limbo.vim", "{install}/syntax_checkers/limbo/limbo.vim"),
      ("syntastic-3.4.0/syntax_checkers/lisp/clisp.vim", "{install}/syntax_checkers/lisp/clisp.vim"),
      ("syntastic-3.4.0/syntax_checkers/llvm/llvm.vim", "{install}/syntax_checkers/llvm/llvm.vim"),
      ("syntastic-3.4.0/syntax_checkers/lua/luac.vim", "{install}/syntax_checkers/lua/luac.vim"),
      ("syntastic-3.4.0/syntax_checkers/matlab/mlint.vim", "{install}/syntax_checkers/matlab/mlint.vim"),
      ("syntastic-3.4.0/syntax_checkers/nasm/nasm.vim", "{install}/syntax_checkers/nasm/nasm.vim"),
      ("syntastic-3.4.0/syntax_checkers/nroff/mandoc.vim", "{install}/syntax_checkers/nroff/mandoc.vim"),
      ("syntastic-3.4.0/syntax_checkers/objc/gcc.vim", "{install}/syntax_checkers/objc/gcc.vim"),
      ("syntastic-3.4.0/syntax_checkers/objc/oclint.vim", "{install}/syntax_checkers/objc/oclint.vim"),
      ("syntastic-3.4.0/syntax_checkers/objcpp/gcc.vim", "{install}/syntax_checkers/objcpp/gcc.vim"),
      ("syntastic-3.4.0/syntax_checkers/objcpp/oclint.vim", "{install}/syntax_checkers/objcpp/oclint.vim"),
      ("syntastic-3.4.0/syntax_checkers/ocaml/camlp4o.vim", "{install}/syntax_checkers/ocaml/camlp4o.vim"),
      ("syntastic-3.4.0/syntax_checkers/perl/perl.vim", "{install}/syntax_checkers/perl/perl.vim"),
      ("syntastic-3.4.0/syntax_checkers/perl/perlcritic.vim", "{install}/syntax_checkers/perl/perlcritic.vim"),
      ("syntastic-3.4.0/syntax_checkers/perl/podchecker.vim", "{install}/syntax_checkers/perl/podchecker.vim"),
      ("syntastic-3.4.0/syntax_checkers/php/php.vim", "{install}/syntax_checkers/php/php.vim"),
      ("syntastic-3.4.0/syntax_checkers/php/phpcs.vim", "{install}/syntax_checkers/php/phpcs.vim"),
      ("syntastic-3.4.0/syntax_checkers/php/phpmd.vim", "{install}/syntax_checkers/php/phpmd.vim"),
      ("syntastic-3.4.0/syntax_checkers/po/msgfmt.vim", "{install}/syntax_checkers/po/msgfmt.vim"),
      ("syntastic-3.4.0/syntax_checkers/pod/podchecker.vim", "{install}/syntax_checkers/pod/podchecker.vim"),
      ("syntastic-3.4.0/syntax_checkers/puppet/puppet.vim", "{install}/syntax_checkers/puppet/puppet.vim"),
      ("syntastic-3.4.0/syntax_checkers/puppet/puppetlint.vim", "{install}/syntax_checkers/puppet/puppetlint.vim"),
      ("syntastic-3.4.0/syntax_checkers/python/compile.py", "{install}/syntax_checkers/python/compile.py"),
      ("syntastic-3.4.0/syntax_checkers/python/flake8.vim", "{install}/syntax_checkers/python/flake8.vim"),
      ("syntastic-3.4.0/syntax_checkers/python/frosted.vim", "{install}/syntax_checkers/python/frosted.vim"),
      ("syntastic-3.4.0/syntax_checkers/python/pep257.vim", "{install}/syntax_checkers/python/pep257.vim"),
      ("syntastic-3.4.0/syntax_checkers/python/pep8.vim", "{install}/syntax_checkers/python/pep8.vim"),
      ("syntastic-3.4.0/syntax_checkers/python/py3kwarn.vim", "{install}/syntax_checkers/python/py3kwarn.vim"),
      ("syntastic-3.4.0/syntax_checkers/python/pyflakes.vim", "{install}/syntax_checkers/python/pyflakes.vim"),
      ("syntastic-3.4.0/syntax_checkers/python/pylama.vim", "{install}/syntax_checkers/python/pylama.vim"),
      ("syntastic-3.4.0/syntax_checkers/python/pylint.vim", "{install}/syntax_checkers/python/pylint.vim"),
      ("syntastic-3.4.0/syntax_checkers/python/python.vim", "{install}/syntax_checkers/python/python.vim"),
      ("syntastic-3.4.0/syntax_checkers/racket/code-ayatollah.vim", "{install}/syntax_checkers/racket/code-ayatollah.vim"),
      ("syntastic-3.4.0/syntax_checkers/racket/racket.vim", "{install}/syntax_checkers/racket/racket.vim"),
      ("syntastic-3.4.0/syntax_checkers/rst/rst2pseudoxml.vim", "{install}/syntax_checkers/rst/rst2pseudoxml.vim"),
      ("syntastic-3.4.0/syntax_checkers/rst/rstcheck.vim", "{install}/syntax_checkers/rst/rstcheck.vim"),
      ("syntastic-3.4.0/syntax_checkers/ruby/jruby.vim", "{install}/syntax_checkers/ruby/jruby.vim"),
      ("syntastic-3.4.0/syntax_checkers/ruby/macruby.vim", "{install}/syntax_checkers/ruby/macruby.vim"),
      ("syntastic-3.4.0/syntax_checkers/ruby/mri.vim", "{install}/syntax_checkers/ruby/mri.vim"),
      ("syntastic-3.4.0/syntax_checkers/ruby/rubocop.vim", "{install}/syntax_checkers/ruby/rubocop.vim"),
      ("syntastic-3.4.0/syntax_checkers/ruby/rubylint.vim", "{install}/syntax_checkers/ruby/rubylint.vim"),
      ("syntastic-3.4.0/syntax_checkers/rust/rustc.vim", "{install}/syntax_checkers/rust/rustc.vim"),
      ("syntastic-3.4.0/syntax_checkers/sass/sass.vim", "{install}/syntax_checkers/sass/sass.vim"),
      ("syntastic-3.4.0/syntax_checkers/scala/fsc.vim", "{install}/syntax_checkers/scala/fsc.vim"),
      ("syntastic-3.4.0/syntax_checkers/scala/scalac.vim", "{install}/syntax_checkers/scala/scalac.vim"),
      ("syntastic-3.4.0/syntax_checkers/scss/sass.vim", "{install}/syntax_checkers/scss/sass.vim"),
      ("syntastic-3.4.0/syntax_checkers/scss/scss_lint.vim", "{install}/syntax_checkers/scss/scss_lint.vim"),
      ("syntastic-3.4.0/syntax_checkers/sh/checkbashisms.vim", "{install}/syntax_checkers/sh/checkbashisms.vim"),
      ("syntastic-3.4.0/syntax_checkers/sh/sh.vim", "{install}/syntax_checkers/sh/sh.vim"),
      ("syntastic-3.4.0/syntax_checkers/sh/shellcheck.vim", "{install}/syntax_checkers/sh/shellcheck.vim"),
      ("syntastic-3.4.0/syntax_checkers/slim/slimrb.vim", "{install}/syntax_checkers/slim/slimrb.vim"),
      ("syntastic-3.4.0/syntax_checkers/tcl/nagelfar.vim", "{install}/syntax_checkers/tcl/nagelfar.vim"),
      ("syntastic-3.4.0/syntax_checkers/tex/chktex.vim", "{install}/syntax_checkers/tex/chktex.vim"),
      ("syntastic-3.4.0/syntax_checkers/tex/lacheck.vim", "{install}/syntax_checkers/tex/lacheck.vim"),
      ("syntastic-3.4.0/syntax_checkers/texinfo/makeinfo.vim", "{install}/syntax_checkers/texinfo/makeinfo.vim"),
      ("syntastic-3.4.0/syntax_checkers/text/atdtool.vim", "{install}/syntax_checkers/text/atdtool.vim"),
      ("syntastic-3.4.0/syntax_checkers/text/language_check.vim", "{install}/syntax_checkers/text/language_check.vim"),
      ("syntastic-3.4.0/syntax_checkers/twig/twiglint.vim", "{install}/syntax_checkers/twig/twiglint.vim"),
      ("syntastic-3.4.0/syntax_checkers/typescript/tsc.vim", "{install}/syntax_checkers/typescript/tsc.vim"),
      ("syntastic-3.4.0/syntax_checkers/vala/valac.vim", "{install}/syntax_checkers/vala/valac.vim"),
      ("syntastic-3.4.0/syntax_checkers/verilog/verilator.vim", "{install}/syntax_checkers/verilog/verilator.vim"),
      ("syntastic-3.4.0/syntax_checkers/vhdl/ghdl.vim", "{install}/syntax_checkers/vhdl/ghdl.vim"),
      ("syntastic-3.4.0/syntax_checkers/vim/vimlint.vim", "{install}/syntax_checkers/vim/vimlint.vim"),
      ("syntastic-3.4.0/syntax_checkers/xhtml/jshint.vim", "{install}/syntax_checkers/xhtml/jshint.vim"),
      ("syntastic-3.4.0/syntax_checkers/xhtml/tidy.vim", "{install}/syntax_checkers/xhtml/tidy.vim"),
      ("syntastic-3.4.0/syntax_checkers/xml/xmllint.vim", "{install}/syntax_checkers/xml/xmllint.vim"),
      ("syntastic-3.4.0/syntax_checkers/xslt/xmllint.vim", "{install}/syntax_checkers/xslt/xmllint.vim"),
      ("syntastic-3.4.0/syntax_checkers/yacc/bison.vim", "{install}/syntax_checkers/yacc/bison.vim"),
      ("syntastic-3.4.0/syntax_checkers/yaml/jsyaml.vim", "{install}/syntax_checkers/yaml/jsyaml.vim"),
      ("syntastic-3.4.0/syntax_checkers/yaml/yamlxs.vim", "{install}/syntax_checkers/yaml/yamlxs.vim"),
      ("syntastic-3.4.0/syntax_checkers/z80/z80syntaxchecker.vim", "{install}/syntax_checkers/z80/z80syntaxchecker.vim"),
      ("syntastic-3.4.0/syntax_checkers/zpt/zptlint.vim", "{install}/syntax_checkers/zpt/zptlint.vim"),
      ("syntastic-3.4.0/syntax_checkers/zsh/shellcheck.vim", "{install}/syntax_checkers/zsh/shellcheck.vim"),
      ("syntastic-3.4.0/syntax_checkers/zsh/zsh.vim", "{install}/syntax_checkers/zsh/zsh.vim"),
    ],
    "symlink": [ ("{install}", "{bundle}") ],
  },
}
